import { Ref } from 'vue';
import { Graffiti, GraffitiSession } from '@graffiti-garden/api';
import { GraffitiSynchronize } from '@graffiti-garden/wrapper-synchronize';
export declare const globals: {
    graffitiSynchronize?: GraffitiSynchronize;
    graffitiSession?: Ref<GraffitiSession | undefined | null>;
};
/**
 * Returns the global [Graffiti](https://api.graffiti.garden/classes/Graffiti.html) instance
 * that has been wrapped by the {@link GraffitiPlugin} with the [GraffitiSynchronize](https://sync.graffiti.garden/classes/GraffitiSynchronize.html).
 * @throws If the {@link GraffitiPlugin} is not installed
 */
export declare function useGraffitiSynchronize(): GraffitiSynchronize;
/**
 * Returns the global [Graffiti](https://api.graffiti.garden/classes/Graffiti.html) instance.
 *
 * In Vue templates and the [options API](https://vuejs.org/guide/introduction.html#options-api)
 * use the global variable {@link ComponentCustomProperties.$graffiti | $graffiti} instead.
 *
 * This is the same Graffiti registered with the {@link GraffitiPlugin}
 * via {@link GraffitiPluginOptions.graffiti}, only it has been wrapped
 * with [GraffitiSynchronize](https://sync.graffiti.garden/classes/GraffitiSynchronize.html).
 * Be sure to use the wrapped instance to enable reactivity.
 *
 * @throws If the {@link GraffitiPlugin} is not installed
 */
export declare function useGraffiti(): Graffiti;
/**
 * Returns a global reactive [GraffitiSession](https://api.graffiti.garden/interfaces/GraffitiSession.html) instance
 * as a [Vue ref](https://vuejs.org/api/reactivity-core.html#ref).
 *
 * In Vue templates and the [options API](https://vuejs.org/guide/introduction.html#options-api)
 * use the global variable {@link ComponentCustomProperties.$graffitiSession | $graffitiSession} instead.
 *
 * While the application is loading and restoring any previous sessions,
 * the value will be `undefined`. If the user is not logged in,
 * the value will be `null`.
 *
 * This only keeps track of one session. If your app needs
 * to support multiple login sessions, you'll need to manage them
 * yourself using [`Graffiti.sessionEvents`](https://api.graffiti.garden/classes/Graffiti.html#sessionevents).
 * @throws If the {@link GraffitiPlugin} is not installed
 */
export declare function useGraffitiSession(): Ref<GraffitiSession | null | undefined, GraffitiSession | null | undefined>;
//# sourceMappingURL=globals.d.ts.map