import { JSONSchema, GraffitiObject, GraffitiObjectStreamContinueEntry, GraffitiObjectStream, GraffitiObjectStreamContinue } from '@graffiti-garden/api';
export declare abstract class Poller<Schema extends JSONSchema> {
    abstract poll(onEntry: (entry: GraffitiObjectStreamContinueEntry<Schema> | null | "clear") => void): Promise<void>;
    abstract clear(): void;
}
/**
 * Polls for a single object and calls onValue with the result.
 */
export declare class GetPoller<Schema extends JSONSchema> implements Poller<Schema> {
    readonly getter: () => Promise<GraffitiObject<Schema>>;
    constructor(getter: () => Promise<GraffitiObject<Schema>>);
    poll: Poller<Schema>["poll"];
    clear(): void;
}
/**
 * Polls for multiple objects and calls `onObject` with the result.
 * If `poll` is called multiple times, it doesn't poll the results
 * entirely from scratch, but instead only polls the new results.
 */
export declare class StreamPoller<Schema extends JSONSchema> implements Poller<Schema> {
    readonly streamFactory: () => GraffitiObjectStream<Schema>;
    iterator: GraffitiObjectStreamContinue<Schema> | undefined;
    continue: (() => GraffitiObjectStreamContinue<Schema>) | undefined;
    constructor(streamFactory: () => GraffitiObjectStream<Schema>);
    clear(): void;
    poll: Poller<Schema>["poll"];
}
//# sourceMappingURL=pollers.d.ts.map