import { Ref } from 'vue';
import { GraffitiObject, Graffiti, JSONSchema, GraffitiObjectStreamContinueEntry } from '@graffiti-garden/api';
export declare abstract class Reducer<Schema extends JSONSchema> {
    abstract clear(): void;
    abstract onEntry(entry: GraffitiObjectStreamContinueEntry<Schema> | null | "clear"): void;
}
/**
 * Retrieves multiple Graffiti objects and retains
 * the most recent one as the `result` property (a Vue ref).
 * Before any objects have been received, the result
 * is `undefined`. If the object has been deleted,
 * the result is `null`.
 */
export declare class SingletonReducer<Schema extends JSONSchema> implements Reducer<Schema> {
    readonly entry: Ref<GraffitiObjectStreamContinueEntry<Schema> | null | undefined>;
    get result(): Ref<GraffitiObject<Schema> | null | undefined>;
    clear(): void;
    onEntry(entry: GraffitiObjectStreamContinueEntry<Schema> | null | "clear"): void;
}
/**
 * Retrieves multiple Graffiti objects and retains
 * the most recent one per URI as the `results` property (a Vue ref).
 * If multiple objects are received concurrently,
 * they are processed in batches every `REFRESH_RATE` milliseconds
 * to avoid freezing the interface.
 */
export declare class ArrayReducer<Schema extends JSONSchema> implements Reducer<Schema> {
    readonly graffiti: Graffiti;
    readonly results: Ref<GraffitiObject<Schema>[]>;
    readonly resultsRaw: Map<string, GraffitiObjectStreamContinueEntry<Schema>>;
    batchFlattenTimer: ReturnType<typeof setTimeout> | undefined;
    constructor(graffiti: Graffiti);
    clear(): void;
    flattenResults(): void;
    onEntry(entry: GraffitiObjectStreamContinueEntry<Schema> | null | "clear"): void;
}
//# sourceMappingURL=reducers.d.ts.map